;; ABSTRACT:

;; NOTE - to get this to run on your computer, you will need an input shape file in the same folder as the model 
;;   The shape file is is actually 6 separate files, named similar to "sites2.shp"  

;; This is an exchange model first developed for the Watts dissertation project... 

;; Variable definitions and code explanations/documentation are provided throughout.

;; In the model view: 
;; Consumers: circles
;; Producers: squares

;; The model imports archaeological site locations from a GIS, places producers and consumers on the provided sites, and 
;; moves pottery from producers to consumers. 

;; Note that each farmer represents a single household at an archaeological site - the model accounts for 
;; differently sized sites or high local population density by placing more households at larger sites.

;; The model runs 1000 ticks on startup to properly set the initial conditions of the simulation.
;; Resulting pottery distributions are output to a csv file after 400 ticks. 

;; Locations and numbers of producers varies depending on temproal phase, and the weighting of different pottery forms is 
;; based on the real ceramic data. Generally these correspond to sources for South Mountain granodiorite, Estrella gneiss, 
;; middle Gila schist, phyllite, and Squaw Peak Schist 

;; Each pot is represented as a list: 
;; [producer owner [list of all past owners] form-(1 or 2) tick-created state-(1 or 0) sherds age-at-break color-(source)] 

;; When the model runs, consumer appearance (size and color) is based on the amount and type (source) of 
;; the pottery in their "midden".

;; Sample settings are described the model "Information" tab.



;; CONTENTS:

;; AGENT and VARIABLE DECLARATIONS:
  ;; extensions
  ;; globals
  ;; breeds
  ;; producer variables
  ;; farmer variables
  
;; MAIN METHODS
  ;; setup
  ;; go

;; SETUP METHODS
  ;; build-world
  ;; make-farmers
  ;; make-producers
  ;; initial-inventory
  ;; farmers-to-sites
  ;; set-up-networks
  ;; display-sites
  
;; GO METHODS
  ;; set-prices
  ;; find-seller
  ;; update-farmer-appearance

;; REPORTING/OUTPUT METHODS
  ;; write-to-file
  
  
  


extensions [ gis nw matrix]

globals [ cems-dataset        ;; data imported from the GIS files
          cems-dataset-short  ;; data imported from the GIS files
          namelist            ;; list of sites active in the current simulation
          colorlist           ;; helps set the colors for the producers 
          makers              ;; identifies subset of patches that are the producers
          prodset             ;; also identifies subset of agents that are the producers
          phz                 ;; used by the GIS import to set other variables (like site populations)
          tracker             ;; tick count for output file
          serial              ;; serial number for output file -- disabled for model review
          sellers             ;; agentset of eligible sellers each time step
          seller<-->buyer     ;; sets the split of transaction costs between buyer and seller (0 = all seller, 10 = all buyer)
          ]

breed [cemetery-labels cemetery-label]  ;; part of the GIS background
breed [farmers farmer]                  ;; consumers
breed [producers producer]              ;; producers
breed [net-builders net-builder]        ;; link-breed that helps set up exchange networks (net-builders die after setup)


producers-own [ ;; a subset of agents are the 'producers'
  form-bias      ;; specifies the production ratio of preferred vessel forms (bowls vs jars) 
  agrlist        ;; a bank account balance of how much agr (agricultural produce) the producer has 
  new-potlist    ;; list of pots currently in the possession of the producer
  price_t        ;; current price willing to sell for
  target_t       ;; identifies which pot will be traded
  f_b            ;; helps keep track of how many pots to produce in the current time step
  network_list   ;; producers sometimes keep track of their network list
  ]

farmers-own [ ;; farmers are the 'consumers'
  sitename       ;; identifies the site where the farmer lives
  potlist        ;; count of intact pots currently owned by the farmer
  new-potlist    ;; list of all pots ownd by the farmer
  pot-ideal      ;; number of pots desired by the farmer
  midden         ;; broken pots owned by the farmer - a trash pile
  want-form      ;; temporary variable to track which form the farmer wants to acquire
  network_list   ;; farmer keeps track of its network list
  agrlist        ;; bank account balance of how much agr (agricultural produce) the farmer has on hand 
  price_t        ;; if selling a used pot, this is the price the farmer will sell for
  target_t       ;; if selling a used pot, this identifies which pot to sell
  last_agr       ;; the amount of agricultural output the farmer had the previous time step
  blist          ;; (bowl list) part of the code that outputs a distance matrix 
  jlist          ;; (jar list) part of the code that outputs a distance matrix  
  plist          ;; (pot list) part of the code that outputs a distance matrix
  link-type      ;; at the end of a run, specifies whether shown links will be for potlist or midden
  ] 








;;
;; SETUP ROUTINE
;; import GIS site locations and demographic data (build-world)
;; define subsets of agents as farmers or producers (make-farmers and make-producers)
;; distribute agents to sites (farmers-to-sites)
;; hook up agents in exchange networks (set-up-networks)
;; show locations for all sites as little red dots (display-sites)
;; draw histogram of the degree distribution for the agent network
;;

to setup 
 
  clear-all
  clear-output
  reset-ticks
  
  build-world
  make-farmers
  make-producers
  farmers-to-sites 
  set-up-networks    
  display-sites
  
  set sellers (turtle-set )
  
 ;; plot degree histogram
   set-current-plot "degree distribution"
   set-plot-pen-mode 1
   let group (turtle-set farmers producers)
   set-plot-x-range 1 (1 + max [length network_list] of group)
   set-plot-pen-interval 1
   histogram [length network_list] of group
   

end  



;;
;; GO ROUTINE 
;; every time step:
;; determine the prices that sellers are willing to sell (set-prices)
;; instructions for the makers (make pots, update agr account)
;; instructions for the farmers (update agr account, break pots)
;; if needed, farmers initiate trade process (find-seller)
;; 

;; basically, in every step each farmer has a probability of breaking a pot in
;; its list of pots (50/50 chance each step). if a pot breaks, or if a farmer's 
;; count of pots drops below a desired level, the farmer calls a helper (below) 
;; to find a seller with a 'surplus' to procure a new pot.

;; also includes some code to convert broken pots to sherds (per Dave's request, unused in the analysis for now)

to go  
 if ticks = 0 [ clear-links ]
 
  set sellers (turtle-set farmers with [length filter [item  5 ? = 1] new-potlist > pot-ideal] 
                          producers with [length filter [item  5 ? = 1] new-potlist > 0 ])
   
  ask makers [ 
;; keep track of agr bank account
;; figure out how many new pots to build and then build them (give pots necessary info too)   
             
              let p_n 0     ;; p_n sets the number of new pots made each times tep
              let j 0
              set agrlist agrlist - 7.5
              
              ;; arbitrarily resets the producer's pot list so that they've got the right ratio of bowls/jars
              
              while [ j < length new-potlist] [
                ifelse length filter [item 3 ? = 1] new-potlist / length new-potlist <= form-bias [ set new-potlist replace-item j new-potlist replace-item 3 item j new-potlist 1] 
                                                                                                  [ set new-potlist replace-item j new-potlist replace-item 3 item j new-potlist 2]
                                                                                                 set j j + 1 ]
              
              ;; updates number of pots to produce based on population and number produced in previous step
              
              ifelse length new-potlist > f_b / 4 [set p_n f_b - random count farmers / 30] [set p_n f_b + random count farmers / 30]
              if p_n < 0 [set p_n 0]
              if length new-potlist < 10 [ set p_n 5 ]
              set f_b floor p_n
              let counts (list round (form-bias * p_n) round ((1 - form-bias) * p_n))
             
              ;; produce the new pots
             
              foreach counts [
               let i 0
               let date ticks
               if date < 1000 [set date round random-normal 990 5]
               while [i < ?] [ set new-potlist lput (list self self (list self) (position ? counts + 1) date 1 1 0 color) new-potlist
                 set i i + 1]
             ] ]       
  
  ask farmers [
 ;; determine how much new agricultural produce to make each time step...    
 ;; update agr account   
             set want-form 0
             set agrlist agrlist - 7.5
             let a_n 0
             if random 100 < 50 [  ifelse agrlist <  10  [set a_n last_agr + 1 ]  [set a_n last_agr - 1 ] 
             if a_n <= 0 [set a_n 0]
             set last_agr a_n ]
             if last_agr < 0 [set last_agr 0]
             if last_agr > 10 [set last_agr 10]
             set agrlist agrlist + last_agr 
    
 ;; check pots, if any broken or too few overall then start the helper to find a replacement.      
             if random-float 1 < .1 and not empty? new-potlist and ticks > 1000 [
              let templist new-potlist
              let dropped one-of new-potlist
              let id position dropped new-potlist
              set dropped replace-item 5 dropped 0
              set dropped replace-item 7 dropped (ticks - item 4 dropped)
              ifelse item 3 dropped = 1 [set dropped replace-item 6 dropped (random 33 + 27)]
                                 [set dropped replace-item 6 dropped (random 40 + 40)]
      
              set new-potlist replace-item id new-potlist dropped
              set want-form item 3 dropped
             ]
            
              ifelse length filter [item 3 ? = 1 and item 5 ? = 1] new-potlist - length filter [item 3 ? = 2 and item 5 ? = 1] new-potlist < 0 
                              [ set want-form 1] [set want-form 2]
              if length filter [item 5 ? = 1] new-potlist < (1.5 * pot-ideal) and agrlist > 3 [find-seller]
              
              ;; update count lists
              
              set potlist list  length filter [item 3 ? = 1 and item 5 ? = 1] new-potlist length filter [item 3 ? = 2 and item 5 ? = 1] new-potlist
              set midden list  length filter [item 3 ? = 1 and item 5 ? = 0] new-potlist length filter [item 3 ? = 2 and item 5 ? = 0] new-potlist
            ]
  
  ;; after 1000 time steps, start updating the Pueblo Grande and La Plaza distribution plots
  
  if ticks > 1000 [
   set-current-plot "PG-distribution"  ;; displays the current ranked buff ware distriubtion at Pueblo Grande
   clear-plot
   set-plot-pen-mode 1
   set-plot-x-range 0 count farmers with [sitename = "Pueblo Grande"]
   let k 0
   let ranked sort [(length filter [item 5 ? = 0 and item 8 ? = 65] new-potlist) / (length filter [item 5 ? = 0] new-potlist) ] of farmers with [sitename = "Pueblo Grande" and length filter [item 5 ? = 0] new-potlist > 0 ]                 
     while [k < length ranked ] [
       plotxy k item k ranked
       set k k + 1]

  if any? farmers with [sitename = "La Plaza"] [   
   set-current-plot "LP-distribution"   ;; displays the current ranked buff ware distriubtion at La Plaza
   clear-plot
   set-plot-pen-mode 1
   set-plot-x-range 0 count farmers with [sitename = "La Plaza"]
   set k 0
   set ranked sort [(length filter [item 5 ? = 0 and item 8 ? = 65] new-potlist) / (length filter [item 5 ? = 0] new-potlist) ] of farmers with [sitename = "La Plaza" and length filter [item 5 ? = 0] new-potlist > 0 ]                 
     while [k < length ranked ] [
       plotxy k item k ranked
       set k k + 1]
    ] ]


  update-farmer-appearance  
  tick
 
;; STOPS after x ticks, writes the data to a txt file saved to the root folder.    

  if ticks = 1401 [              
    set tracker ticks 
    write-to-file   
   stop
    ]
  
end










  

to build-world

;; GIS IMPORT & SET UP THE WORLD
  set cems-dataset gis:load-dataset "sites2.shp"
  gis:set-world-envelope [ -112.24370115723903 -111.54211989526184  33.17637204108411 33.58525130178374 ]
    ; 33.07637204108411 33.68525130178374 ] 
  resize-world (-37) (37) 
               (-25) (25)
  set cems-dataset-short []
  let blarg gis:feature-list-of cems-dataset

  if phase = 2 [ set phz "sz2" ]   ;; temporal phases of the Hohokam sequence
  if phase = 3 [ set phz "sz3" ]
  if phase = 4 [ set phz "sz4" ]
  if phase = 5 [ set phz "sz5" ]
  
end


to make-farmers
;; SET NUMBER OF FARMERS, SET BASIC FARMER VARIABLES
;; checks GIS database to determine agent populations based on the phase selected
  let numb 0
  let farmer_count []
  let sze []
    set farmer_count gis:feature-list-of cems-dataset 
      foreach  farmer_count [
        let locations gis:location-of (first (first (gis:vertex-lists-of ?)))
        set sze lput gis:property-value ? phz sze
        ]  
      let f_c sum sze
      set sze remove nobody sze

;; farmer (consumers) basics, number of farmers   
    set-default-shape farmers "circle"
      set f_c map [ceiling (? / 5)] sze
      set numb sum f_c  

  create-farmers numb [
      set color blue
      set size .5
      set pot-ideal 5 + random 5
      set xcor random 10
      set ycor random 10
      set want-form one-of [1 2]
      set network_list []
      set price_t 1
      ] 
  
;; farmers keep track of lists of current agr supply
    ask farmers [
      set agrlist 10
      set last_agr 10
      set new-potlist []
      ]
    
end

to make-producers

;; SET NUMBER OF PRODUCERS, SET BASIC PRODUCER VARIABLES
;; identify which agents are producers
;; give those patches unique colors and assign them a producer
;; give that producer some specs depending on temporal phase
   set colorlist (list)
    let tempcolor 25
    let maker-patches []
    let ratio-set []
    let phz-makers 0

    if phase = 2 [ set maker-patches (list patch -22 8 "" "" patch -6 0 "" patch 1 -18 )
                   set ratio-set (list 0.667 "" "" 0.0 "" 0.5)
                   set phz-makers 3 ]  
    if phase = 3 [ set maker-patches (list patch -22 8 "" "" patch -6 0 patch -3 -17 patch 1 -18)
                   set ratio-set (list 0.34 "" "" 0.14 0.9 0.36)
                   set phz-makers 4 ]
    if phase = 4 [ set maker-patches (list patch -22 8 "" patch -19 1 patch -6 0 patch -3 -17 patch 1 -18)
                   set ratio-set (list 0.44 "" 0.09 0.17 0.88 0.5)                   
                   set phz-makers 5 ]
    if phase = 5 [ set maker-patches (list patch -22 8 patch -20 10 "" "" patch -3 -17 patch 1 -18)
                   set ratio-set (list 0.6 0.62 "" "" 0.83 0.49) 
                   set phz-makers 4 ]
    
    let  active_makers [-22 8 -20 10 -19 1 -6 0 -3 -17 1 -18 33 25]
    let multiplier 40
      set prodset []
   
    (foreach maker-patches ratio-set [ if is-patch? ?1 [ ask ?1 [sprout-producers multiplier [
      set shape "square" 
      set color tempcolor 
      set form-bias ?2
      set prodset lput self prodset
      set network_list []
      set new-potlist []
      set agrlist 10
      set price_t 1
      set heading random-float 360
      fd (random-float 10) / 10] ] ]       
     set colorlist lput tempcolor colorlist
     set tempcolor tempcolor + 20  ]) 
     set makers producers with [shape = "square"]

    initial-inventory
    
end
    

to farmers-to-sites
;; moves farmers to a specified subset of the sites
;; also assigns a site name to the farmer (from the GIS)
;; Puts the right number of farmers on the site based on Doelle's demographic 
;; numbers for different time periods. 

  let here 0
  let xlist []
  let ylist []
  set namelist []
  let sz3 []
  
;; parses GIS file  
  set here gis:feature-list-of cems-dataset
   foreach  here [
        let location gis:location-of (first (first (gis:vertex-lists-of ?)))
        let sz gis:property-value ? phz
        if not empty? location and is-number? sz
         [ set xlist lput item 0 location xlist
           set ylist lput item 1 location ylist
           set namelist lput gis:property-value ? "SITE_NAME" namelist
           set sz3 lput gis:property-value ? phz sz3
           ] ]

;; distributes farmers on the landscape (in the right places in the right numbers)   
   let i 0 
   let j 0
   let l 0
   foreach sort farmers [
    ask ? [
     while [item j sz3 = 0] [ set j j + 1]
     set l item j sz3 / 5  
     set l ceiling l
     setxy item j xlist item j ylist   
     set size .5 
     set heading random-float 360
     fd (random-float 10) / 10
     set color green  
     set sitename item j namelist
     set i i + 1
     if i =  l [ set j j + 1
                set i 0 
                set l 0]
      ] ] 
   
end  



to initial-inventory
;;  SET INITIAL INVENTORY OF POTS FOR PRODUCERS    
       ask makers [ 
              set f_b count farmers / 90
              let counts (list (form-bias * f_b) ((1 - form-bias) * f_b))
              foreach counts [
               let i 0
               let date ticks
               if date < 1000 [set date round random-normal 990 5]
               while [i < ?] [ set new-potlist lput (list self self (list self) (position ? counts + 1) date 1 1 0 color) new-potlist
                 set i i + 1]
              ]]   
                   
end               
   

       
to set-up-networks
;; Code to give the agents necessary info to particpate in the economy. 
;; Ask farmers to set up their personal list of exchange partners, depending on switch/slider 
;; settings on interface.

 let group (turtle-set farmers makers)
   
 
;; ROUTINE TO BUILD A SCALE-FREE NETWORK   
;; uses a preferential attachment rule
;; net-power parameter shifts just how heavily to prefer existing contacts, range 0-2;
;; 0 means no pref, 1 is standard pref-attach, 2 creates an almost-star network

if net-type = 1 [
  
      ask group [  
             let total random-float sum [length network_list ^ net-power] of group  
             let partner nobody
             ask group  [
               let nc length network_list ^ net-power
            ;; if there's no winner yet...
               if partner = nobody [
                 ifelse nc > total
                 [ set partner self 
                   set network_list lput myself network_list ]
                 [ set total total - nc ]
              ] ]
             set network_list lput partner network_list
           ]  ]
 
;; this version of preferential attachement is from the nw extension, finding it hogs RAM (memory leak?); 
;; much faster and less memory needed to simply use the code above      
;            nw:generate-preferential-attachment net-builders links (count farmers + count producers) 
;                    (foreach sort group sort net-builders [
;                        ask ?1 [
;                          set network_list [link-neighbors] of ?2
;                          set network_list sort network_list
;                          set network_list map [position ? sort net-builders] network_list
;                          set network_list map [item ? sort group] network_list
;                        ] ])                  

  
;; ROUTINE TO BUILD A RANDOM NETWORK, DEGREE NORMALLY DISTRIBUTED 
;; each agent has a 0.02 chance of being attached to each other agent.
  
 if net-type = 2 [   nw:generate-random net-builders links (count farmers + count producers) 0.02
                    (foreach sort group sort net-builders [
                        ask ?1 [
                          set network_list [link-neighbors] of ?2
                          set network_list sort network_list
                          set network_list map [position ? sort net-builders] network_list
                          set network_list map [item ? sort group] network_list
                        ]
                    ])  
                    ]


;; ROUTINE TO BUILD A DISTANCE-WEIGHTED SCALE-FREE NETWORK   
;; uses a preferential attachment rule, except that the preference is for distance
;; sort of like a nearest neighbor network, but allows for some longer distance attachments
if net-type = 3 [
         ask group [  
             let temp-group other group   
              ; ask temp-group [show distance-nowrap myself]
             let total random-float sum  [(( 1 / (.0001 + distance-nowrap myself )) * 10) ^ net-power] of temp-group           
             let partner nobody
             ask temp-group [
               let nc ((1 / (.0001 + distance-nowrap myself)) * 10) ^ net-power
             ;; if there's no winner yet...
               if partner = nobody [
                 ifelse nc > total
                 [ set partner self 
                   set network_list lput myself network_list]
                 [ set total total - nc ]
               ] ]
             set network_list lput partner network_list
           ] ]
            
 
;; other network cleanup, shows network statistics at setup
 ask farmers [ set network_list remove nobody network_list
              set network_list remove self network_list
              set network_list remove-duplicates network_list
              foreach sort network_list [ create-link-with ? ]
             ]
        ask net-builders [die]            
        nw:set-context turtles links
        let dist-list []
 ask farmers [ 
    if min-one-of producers [nw:distance-to myself] != nobody [
    set dist-list lput [nw:distance-to myself] of min-one-of producers [nw:distance-to myself] dist-list] ]
 
   type mean dist-list type " ; " type standard-deviation dist-list type " ; " print max dist-list

end
  


to display-sites
;;  takes GIS input and draws dots on the landscape
   foreach gis:feature-list-of cems-dataset
    [ gis:set-drawing-color red 
      gis:fill ? 2.0
    ]
end
  


to find-seller
;; Helper to determine who to acquire a pot from, and moves the pot to a new owner.
;; The code here simply goes to the pre-defined network list from the setup code and 
;; grabs the cheapest producer or farmer given the distance-weight settings.  
  
  let target 0
  let price 0
  let tcs 0
  let tcb 0
  let frm want-form
  

  ;; Go through list of possible sellers, ask them to report their price and figure out the
  ;; distance-based transaction cost of doing business. 
    
    let t-sellers (turtle-set )
    set t-sellers (turtle-set network_list) with [member? self sellers and length filter [item  5 ? = 1 and item 3 ? = frm] new-potlist > 4]
    
    set seller<-->buyer 10  ;; all transaction costs paid by the buyer

  ;; if soft-net? is true, and no sellers in immediate network, check all friends of friends for possible sellers        
    if not any? t-sellers and soft-net? [    
    let twoD (turtle-set )
     foreach network_list [ ask ? [
       set twoD (turtle-set twoD (turtle-set network_list) with [member? self sellers and length filter [item  5 ? = 1 and item 3 ? = frm] new-potlist > 4])
        ] ]
    set t-sellers (turtle-set t-sellers twoD)  ]

   let seller nobody
   
   if any? t-sellers [ 
          set seller min-one-of t-sellers [price_t + ((seller<-->buyer * d-weight * distance-nowrap myself) / 10000) ]
               if seller != nobody [set price [price_t + ((seller<-->buyer * d-weight * distance-nowrap myself) / 10000)] of seller 
               set tcb (seller<-->buyer * d-weight * distance-nowrap seller) / 10000
               set tcs (10 - (seller<-->buyer * d-weight * distance-nowrap seller)) / 10000
                    ] ] 
                                         
     if seller != nobody [ set target [ position one-of filter [item 3 ? = frm and item 5 ? = 1 ] new-potlist new-potlist] of seller  ]
     if price > 10  [ set seller nobody ]
 
  ;; moves the pot to the buyer, updates lists and accounts   
         if seller != nobody [
           let update-pot []
           set update-pot [item target new-potlist] of seller
           set update-pot replace-item 1 update-pot self
           set update-pot replace-item 2 update-pot lput self item 2 update-pot
           set new-potlist lput update-pot new-potlist
            ask seller [
              if is-farmer? self [set want-form item 3 item target new-potlist]
                 set new-potlist remove-item target new-potlist
                 set agrlist agrlist + price - tcs ]
           set agrlist agrlist - price ]
                     
end  



to update-farmer-appearance 
;; node procedure
;; scale the size and adjust color  
  ask farmers [
    if length filter [item 5 ? = 0] new-potlist > 0 [
    let rlist []
    let glist []
    let blulist []
 
    foreach filter [item 5 ? = 0] new-potlist [
    set rlist fput item 0 extract-rgb item 8 ? rlist
    set glist fput item 1 extract-rgb item 8 ? glist
    set blulist fput item 2 extract-rgb item 8 ? blulist ]
    set color (list mean rlist mean glist mean blulist) ]
    set size 0.1 + 5 * sqrt (length filter [item 5 ? = 0] new-potlist / 400) ] 
 
end



to write-to-file
 ;;  set up the files to output for each simulation
 ;;  saves a png of the view at the end of the simulation.
 ;;  saves a csv with the pottery counts (midden) for all of the consumer agents. 
 
set serial "TEST"

   let view_file (word serial "_N" net-type "_" d-weight "_" soft-net? "_" tracker "_RAW" "_view" ".png")
    if file-exists? view_file [file-delete view_file]
   export-view view_file

  ;; create new output file with settings and serial in the filename 
   let file_output (word serial "_N" net-type "_" d-weight "_" soft-net? "_" tracker "_RAW"  ".csv")
    if file-exists? file_output [ file-delete file_output ]
   file-open file_output 

  foreach sort farmers [
    ask ? [
    set blist []
    set jlist []
    set plist []
    let b_sherd_count []
    let j_sherd_count []
      foreach sort colorlist [
         let col ? 
         set plist lput length filter [item 5 ? = 0 and item 8 ? = col] new-potlist plist
         set blist lput length filter [item 3 ? = 1 and item 5 ? = 0 and item 8 ? = col] new-potlist blist
         set jlist lput length filter [item 3 ? = 2 and item 5 ? = 0 and item 8 ? = col] new-potlist jlist
      
      let temp_sherds 0
      foreach filter [item 5 ? = 0 and item 3 ? = 1 and item 8 ? = col] new-potlist [set temp_sherds temp_sherds + item 6 ? ]
       set b_sherd_count lput temp_sherds b_sherd_count
      set temp_sherds 0
      foreach filter [item 5 ? = 0 and item 3 ? = 2 and item 8 ? = col] new-potlist [set temp_sherds temp_sherds + item 6 ? ] 
       set j_sherd_count lput temp_sherds j_sherd_count        
      ]
      
    file-type "Agent-" file-type who file-type "," file-write sitename file-type ","
    file-type reduce word map [word ? ","] plist 
    file-type reduce word map [word ? ","] blist 
    file-type reduce word map [word ? ","] b_sherd_count 
    file-type reduce word map [word ? ","] jlist 
    file-type reduce word map [word ? ","] j_sherd_count 
    file-print network_list    ]  ]
   file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
264
10
1024
551
37
25
10.0
1
10
1
1
1
0
0
0
1
-37
37
-25
25
1
1
1
ticks
30.0

BUTTON
96
131
179
164
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
8
130
85
163
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
189
132
247
165
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
121
48
227
81
d-weight
d-weight
0
10
0
.1
1
NIL
HORIZONTAL

SLIDER
11
10
111
43
net-type
net-type
1
3
1
1
1
NIL
HORIZONTAL

SLIDER
68
84
166
117
phase
phase
2
5
4
1
1
NIL
HORIZONTAL

SLIDER
12
47
111
80
net-power
net-power
0
2
1
.1
1
NIL
HORIZONTAL

PLOT
5
170
258
290
degree distribution
NIL
NIL
1.0
15.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

PLOT
4
294
258
414
PG-distribution
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SWITCH
121
11
227
44
soft-net?
soft-net?
1
1
-1000

PLOT
5
419
257
539
LP-distribution
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

@#$#@#$#@
## QUESTIONS?

Can we better interpret the distribution of artifacts in the empirical archaeological record by comparing that data to output from simulations of the economic exchange systems that distributed those goods? 

## WHAT IS IT?

This is a relatively simple model of the prehistoric Hohokam economy, focused on two goods (pottery and agricultural produce). Depending on settings, the model can be tuned to distribute pottery through highly restricted networks or through open (more market-like) exchange systems. 

Aspects drawn from real Hohokam system include a GIS input of approximate site locations, with the populations at those sites drawn (as best possible) from sparse literature on demographics. These inputs are adjustable according to the temporal phases outlined in my proposal. Similarly, the producers agents are placed in the right places and times relative to the sites/populations. The producers also build vessel forms at ratios observed in the real data (e.g. the South Mountain granodiorite producer emphasizes the production of jars - about 70% of their output). 

While the model interface looks somewhat complicated due to the adjustable settings, I emphasize that most of those settings are there only so that a range model sub-types packaged in a single overall NetLogo model (as opposed to have separate Netlogo file for each model subtype). The underlying code is actually fairly simple and thoroughly documented.

## INSTRUCTIONS

The accompanying shape file, which includes 6 loose files, with the name "sites2" must be placed in the same folder as the NetLogo file. 

To run a simulation, first select options on the sliders (see below), then hit the setup button. On most PC's, the setup will take 5-15 seconds depending on the number of agents specified for the particular phase. Then hit GO. The simulation will run 1000 time steps with no changes to the display. After 1000 time steps the view will be updated every time step to 400 ticks, and it stops at 1401 ticks. 

At 1401 ticks a report of all the pottery distributed to the agents is generated as a .csv file, and a .png image of the view is saved. Both files are saved in the current folder of the model. 

I have developed a number of NetLogo scripts for summarizing the output data -- contact me if you are interested. 

## ODD MODEL SPECIFICATION

A full ODD spec of the model is available as a pdf via the OpenABM library.  


## SWITCHES, SLIDERS, AND BUTTONS

* net-type * Slider that sets the network in which pottery moves from producers to consumers. Eight settings: 
	1 - Scale free (preferential attachment method, see *net-power*)
	2 - Random (agents linked to other agents with 0.02 probability) 
	3 - Spatially weighted scale-free (preferential attachment by distance)

* degree * Slider that works with net-types 3 and 4 (nearest neighbor and random) to set the number of network ties for each   
farmer in the model. 

* net-power * Slider that works with net-type 1 (scale free) to adjust the centrality   
of the network. 

* phase * Slider that sets the population of farmers and their locations according to demographic work of Doelle et al. Four settings:
	2 - Corresponds to the Vahki phase (A.D. 450-500), 16 active sites, 300 households 
	3 - Corresponds to the Estrella through early Sacaton phases (A.D. 500-1020), 37 active sites, 951 households 
	4 - Corresponds to the middle Sacaton phase (A.D. 1020-1070), 39 active sites, 1222 households 
	5 - Corresponds to the late Sacaton through Civano/Polveron? phases (A.D. 1070-1450) 38 active sites, 1743 households 

* soft-net? * Switch that sets how strictly agents buy/sell within their exchange network
	off - Buyers are only able to purchase from other agents in their network
	on - Buyers are able to purchase two steps out in their network; they can buy from a friend-of-a-friend

* d-weight * Slider that adjusts the cost of moving pottery across the landscape; a 'distance-weight' for calculating transaction costs to the buyer. 


@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment_1" repetitions="72" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="30"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_2" repetitions="80" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="30"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="marketplace?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set1_random" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set2_complete" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set3_nearest" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set4_scalefree" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set5_centralized" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set6_kinshipA" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set7_kinshipB" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set8_marketplace" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set9_shopkeeper" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set10_workshop" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set11_peddler" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="set12_individual" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="side_test1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="100"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="side_test2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="100"/>
    <metric>count turtles</metric>
    <metric>net-type</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="side_test3" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="100"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sat_test_1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="1200"/>
    <metric>count turtles</metric>
    <metric>net-type</metric>
    <metric>tracker</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sat_test_2" repetitions="4" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="1200"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sat_test_3" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="700"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="3"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="tue_test_1" repetitions="25" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-to-file
make-matrix</final>
    <timeLimit steps="1400"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="6"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scale_dep_1" repetitions="24" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1800"/>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="resale?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-op?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-point">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="periodic-market?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_d">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middlemen?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info_s">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="subset?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="marketplace?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20140823" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1401"/>
    <enumeratedValueSet variable="soft-net?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="market-based?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seller&lt;--&gt;buyer">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20140902" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1401"/>
    <enumeratedValueSet variable="soft-net?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="d-weight">
      <value value="0"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-type">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="phase">
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="net-power">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
